@@ -26,6 +26,7 @@ pub struct KeyConfig {
     pub tab_stashes: KeyEvent,
     pub tab_toggle: KeyEvent,
     pub tab_toggle_reverse: KeyEvent,
+    pub toggle_workarea: KeyEvent,
     pub focus_right: KeyEvent,
     pub focus_left: KeyEvent,
     pub focus_above: KeyEvent,
@@ -55,6 +56,7 @@ pub struct KeyConfig {
     pub stashing_save: KeyEvent,
     pub stashing_toggle_untracked: KeyEvent,
     pub stashing_toggle_index: KeyEvent,
+    pub stash_apply: KeyEvent,
     pub stash_open: KeyEvent,
     pub stash_drop: KeyEvent,
     pub cmd_bar_toggle: KeyEvent,
@@ -80,6 +82,7 @@ impl Default for KeyConfig {
 			tab_stashes: KeyEvent { code: KeyCode::Char('4'), modifiers: KeyModifiers::empty()},
 			tab_toggle: KeyEvent { code: KeyCode::Tab, modifiers: KeyModifiers::empty()},
 			tab_toggle_reverse: KeyEvent { code: KeyCode::BackTab, modifiers: KeyModifiers::SHIFT},
+            toggle_workarea: KeyEvent { code: KeyCode::Char('w'), modifiers: KeyModifiers::empty()},
 			focus_right: KeyEvent { code: KeyCode::Right, modifiers: KeyModifiers::empty()},
 			focus_left: KeyEvent { code: KeyCode::Left, modifiers: KeyModifiers::empty()},
 			focus_above: KeyEvent { code: KeyCode::Up, modifiers: KeyModifiers::empty()},
@@ -109,6 +112,7 @@ impl Default for KeyConfig {
 			stashing_save: KeyEvent { code: KeyCode::Char('s'), modifiers: KeyModifiers::empty()},
 			stashing_toggle_untracked: KeyEvent { code: KeyCode::Char('u'), modifiers: KeyModifiers::empty()},
 			stashing_toggle_index: KeyEvent { code: KeyCode::Char('i'), modifiers: KeyModifiers::empty()},
+			stash_apply: KeyEvent { code: KeyCode::Char('a'), modifiers: KeyModifiers::empty()},
 			stash_open: KeyEvent { code: KeyCode::Right, modifiers: KeyModifiers::empty()},
 			stash_drop: KeyEvent { code: KeyCode::Char('D'), modifiers: KeyModifiers::SHIFT},
 			cmd_bar_toggle: KeyEvent { code: KeyCode::Char('.'), modifiers: KeyModifiers::empty()},
@@ -268,10 +272,8 @@ mod tests {
     #[test]
     fn test_load_vim_style_example() {
         assert_eq!(
-            KeyConfig::read_file(
-                "assets/vim_style_key_config.ron".into()
-            )
-            .is_ok(),
+            KeyConfig::read_file("vim_style_key_config.ron".into())
+                .is_ok(),
             true
         );
     }
