@@ -19,8 +19,9 @@ pub static PUSH_TAGS_STATES_FETCHING: &str = "fetching";
 pub static PUSH_TAGS_STATES_PUSHING: &str = "pushing";
 pub static PUSH_TAGS_STATES_DONE: &str = "done";
 
-pub static SELECT_BRANCH_POPUP_MSG: &str = "Switch Branch";
-
+pub fn title_branches() -> String {
+    "Branches".to_string()
+}
 pub fn title_status(_key_config: &SharedKeyConfig) -> String {
     "Unstaged Changes".to_string()
 }
@@ -89,6 +90,11 @@ pub fn confirm_title_stashdrop(
 ) -> String {
     "Drop".to_string()
 }
+pub fn confirm_title_stashpop(
+    _key_config: &SharedKeyConfig,
+) -> String {
+    "Pop".to_string()
+}
 pub fn confirm_title_merge(
     _key_config: &SharedKeyConfig,
     rebase: bool,
@@ -127,6 +133,10 @@ pub fn confirm_msg_stashdrop(
 ) -> String {
     "confirm stash drop?".to_string()
 }
+pub fn confirm_msg_stashpop(_key_config: &SharedKeyConfig) -> String {
+    "The stash will be applied and removed from the stash list. Confirm stash pop?"
+        .to_string()
+}
 pub fn confirm_msg_resethunk(
     _key_config: &SharedKeyConfig,
 ) -> String {
@@ -503,6 +513,30 @@ pub mod commands {
             CMD_GROUP_GENERAL,
         )
     }
+    pub fn select_staging(
+        key_config: &SharedKeyConfig,
+    ) -> CommandText {
+        CommandText::new(
+            format!(
+                "To stage [{}]",
+                key_config.get_hint(key_config.toggle_workarea),
+            ),
+            "focus/select staging area",
+            CMD_GROUP_GENERAL,
+        )
+    }
+    pub fn select_unstaged(
+        key_config: &SharedKeyConfig,
+    ) -> CommandText {
+        CommandText::new(
+            format!(
+                "To unstaged [{}]",
+                key_config.get_hint(key_config.toggle_workarea),
+            ),
+            "focus/select unstaged area",
+            CMD_GROUP_GENERAL,
+        )
+    }
     pub fn commit_open(key_config: &SharedKeyConfig) -> CommandText {
         CommandText::new(
             format!(
@@ -717,7 +751,7 @@ pub mod commands {
         CommandText::new(
             format!(
                 "Apply [{}]",
-                key_config.get_hint(key_config.enter),
+                key_config.get_hint(key_config.stash_apply),
             ),
             "apply selected stash",
             CMD_GROUP_STASHES,
@@ -735,6 +769,18 @@ pub mod commands {
             CMD_GROUP_STASHES,
         )
     }
+    pub fn stashlist_pop(
+        key_config: &SharedKeyConfig,
+    ) -> CommandText {
+        CommandText::new(
+            format!(
+                "Pop [{}]",
+                key_config.get_hint(key_config.enter),
+            ),
+            "pop selected stash",
+            CMD_GROUP_STASHES,
+        )
+    }
     pub fn stashlist_inspect(
         key_config: &SharedKeyConfig,
     ) -> CommandText {
@@ -855,6 +901,32 @@ pub mod commands {
             CMD_GROUP_GENERAL,
         )
     }
+    pub fn select_branch_popup(
+        key_config: &SharedKeyConfig,
+    ) -> CommandText {
+        CommandText::new(
+            format!(
+                "Checkout [{}]",
+                key_config.get_hint(key_config.enter),
+            ),
+            "checkout branch",
+            CMD_GROUP_GENERAL,
+        )
+    }
+    pub fn toggle_branch_popup(
+        key_config: &SharedKeyConfig,
+        local: bool,
+    ) -> CommandText {
+        CommandText::new(
+            format!(
+                "{} [{}]",
+                if local { "Remote" } else { "Local" },
+                key_config.get_hint(key_config.tab_toggle),
+            ),
+            "toggle branch type (remote/local)",
+            CMD_GROUP_GENERAL,
+        )
+    }
     pub fn open_branch_select_popup(
         key_config: &SharedKeyConfig,
     ) -> CommandText {
